--- funcs/func_logic.c	2007-10-23 23:18:08.000000000 +0200
+++ funcs/func_logic.c	2008-02-06 21:28:57.000000000 +0100
@@ -148,6 +148,53 @@
 	return 0;
 }
 
+static int acf_chanvar_read(struct ast_channel *chan, char *cmd, char *data, char *buf,
+			    size_t len)
+{
+        AST_DECLARE_APP_ARGS(args,
+                AST_APP_ARG(channel);
+                AST_APP_ARG(varname);
+        );
+        AST_STANDARD_APP_ARGS(args, data);
+        buf[0] = 0;
+        if (!ast_strlen_zero(args.channel) & !ast_strlen_zero(args.varname)) {
+                struct ast_channel *chan2 = ast_get_channel_by_name_locked(args.channel);
+                if (chan2) {
+                        char *s = alloca(strlen(args.varname) + 4);
+                        if (s) {
+                                sprintf(s, "${%s}", args.varname);
+                                pbx_substitute_variables_helper(chan2, s, buf, len);
+	                }
+	                ast_channel_unlock(chan2);
+	        } else 
+			ast_log(LOG_NOTICE, "Channel: %s does not exist!\n", args.channel);
+	} else 
+		ast_log(LOG_ERROR, "Usage: Set(foo=${CHANVAR(<channel>,<variable>)})\n");
+		
+	return 0;
+}
+
+static int acf_chanvar_write(struct ast_channel *chan, char *cmd, char *var, const char *value)
+{
+	AST_DECLARE_APP_ARGS(args,
+                AST_APP_ARG(channel);
+                AST_APP_ARG(varname);
+        );
+        AST_STANDARD_APP_ARGS(args, var);
+        if (!ast_strlen_zero(args.channel) & !ast_strlen_zero(args.varname)) {
+                struct ast_channel *chan2 = ast_get_channel_by_name_locked(args.channel);
+                if (chan2) {
+			pbx_builtin_setvar_helper(chan2, args.varname, value);
+			ast_channel_unlock(chan2);
+	    	} else
+			ast_log(LOG_NOTICE, "Channel: %s does not exist!\n", args.channel);        
+	} else
+		ast_log(LOG_ERROR, "Usage: Set(CHANVAR(<channel>,<variable>)=value)\n");
+
+	return 0;
+}
+
+
 static struct ast_custom_function isnull_function = {
 	.name = "ISNULL",
 	.synopsis = "NULL Test: Returns 1 if NULL or 0 otherwise",
@@ -185,6 +232,20 @@
 	.read = iftime,
 };
 
+static struct ast_custom_function chanvar_function = {
+        .name = "CHANVAR",
+	.synopsis =
+                "Reads or writes a variables from or to another channel.\n",
+        .syntax = "CHANVAR(channel,variable)",
+	.desc =
+		"Reads or writes a variables from or to another channel.\n"
+		"Examples;\n"
+		"Read:  Set(foo=${CHANVAR(${BRIDGEPEER},UNIQUEID)})\n"
+		"Write: Set(CHANVAR(${BRIDGEPEER},UNIQUEID)=${foo})\n",
+        .read = acf_chanvar_read,
+	.write = acf_chanvar_write,
+};
+
 static int unload_module(void)
 {
 	int res = 0;
@@ -194,7 +255,8 @@
 	res |= ast_custom_function_unregister(&exists_function);
 	res |= ast_custom_function_unregister(&if_function);
 	res |= ast_custom_function_unregister(&if_time_function);
-
+        res |= ast_custom_function_unregister(&chanvar_function);
+	
 	return res;
 }
 
@@ -207,7 +269,8 @@
 	res |= ast_custom_function_register(&exists_function);
 	res |= ast_custom_function_register(&if_function);
 	res |= ast_custom_function_register(&if_time_function);
-
+        res |= ast_custom_function_register(&chanvar_function);
+	
 	return res;
 }
 
